import { ChangeDetectionStrategy, Component, ElementRef, EventEmitter, Input, NgZone, Output, NgModule } from '@angular/core';
import { take, distinctUntilChanged, debounceTime, takeUntil } from 'rxjs/operators';
import { fromEvent, Subject } from 'rxjs';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EChartsComponent {
    /**
     * @param {?} _elementRef
     * @param {?} _ngZone
     */
    constructor(_elementRef, _ngZone) {
        this._elementRef = _elementRef;
        this._ngZone = _ngZone;
        this.chartClick = new EventEmitter();
        this.chartDblClick = new EventEmitter();
        this.chartMouseDown = new EventEmitter();
        this.chartMouseUp = new EventEmitter();
        this.chartMouseOver = new EventEmitter();
        this.chartMouseOut = new EventEmitter();
        this.chartGlobalOut = new EventEmitter();
        this.chartContextMenu = new EventEmitter();
        this.chartDataZoom = new EventEmitter();
        this._loaded = false;
        this._destroy$ = new Subject();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        // Wait for stabalization so the viewport is rendered
        this._ngZone.onStable
            .pipe(take(1))
            .subscribe(() => this._createChart());
        this._ngZone.runOutsideAngular(() => {
            fromEvent(window, 'resize')
                .pipe(distinctUntilChanged(), debounceTime(10), takeUntil(this._destroy$)).subscribe(() => this.resize());
        });
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (this._chart && this._loaded) {
            const /** @type {?} */ result = {};
            for (const /** @type {?} */ change in changes) {
                if (this[change]) {
                    result[change] = changes[change].currentValue;
                }
            }
            this.setOptions(result);
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this._chart) {
            this._chart.dispose();
            this._chart = null;
        }
        this._destroy$.next();
        this._destroy$.complete();
    }
    /**
     * @return {?}
     */
    resize() {
        if (this._chart) {
            this._chart.resize();
        }
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    setOptions(changes) {
        this._chart.setOption(changes);
    }
    /**
     * @return {?}
     */
    _createChart() {
        this._ngZone.runOutsideAngular(() => {
            this._chart = echarts.init(this._elementRef.nativeElement, this.theme);
            this._chart.on('click', e => this._ngZone.run(() => this.chartClick.emit(e)));
            this._chart.on('dblClick', e => this._ngZone.run(() => this.chartDblClick.emit(e)));
            this._chart.on('mousedown', e => this._ngZone.run(() => this.chartMouseDown.emit(e)));
            this._chart.on('mouseup', e => this._ngZone.run(() => this.chartMouseUp.emit(e)));
            this._chart.on('mouseover', e => this._ngZone.run(() => this.chartMouseOver.emit(e)));
            this._chart.on('mouseout', e => this._ngZone.run(() => this.chartMouseOut.emit(e)));
            this._chart.on('globalout', e => this._ngZone.run(() => this.chartGlobalOut.emit(e)));
            this._chart.on('contextmenu', e => this._ngZone.run(() => this.chartContextMenu.emit(e)));
            this._chart.on('datazoom', e => this._ngZone.run(() => this.chartDataZoom.emit(e)));
            this.setOptions({
                visualMap: this.visualMap,
                title: this.title,
                tooltip: this.tooltip,
                legend: this.legend,
                series: this.series,
                xAxis: this.xAxis,
                yAxis: this.yAxis,
                animation: this.animation
            });
            this._loaded = true;
        });
    }
}
EChartsComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-echart',
                template: `<ng-content></ng-content>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                host: {
                    '[class.ngx-echart]': 'true'
                }
            },] },
];
/** @nocollapse */
EChartsComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: NgZone }
];
EChartsComponent.propDecorators = {
    theme: [{ type: Input }],
    title: [{ type: Input }],
    tooltip: [{ type: Input }],
    legend: [{ type: Input }],
    series: [{ type: Input }],
    loading: [{ type: Input }],
    xAxis: [{ type: Input }],
    yAxis: [{ type: Input }],
    visualMap: [{ type: Input }],
    animation: [{ type: Input }],
    chartClick: [{ type: Output }],
    chartDblClick: [{ type: Output }],
    chartMouseDown: [{ type: Output }],
    chartMouseUp: [{ type: Output }],
    chartMouseOver: [{ type: Output }],
    chartMouseOut: [{ type: Output }],
    chartGlobalOut: [{ type: Output }],
    chartContextMenu: [{ type: Output }],
    chartDataZoom: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EChartsModule {
}
EChartsModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [EChartsComponent],
                exports: [EChartsComponent]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { EChartsModule, EChartsComponent };
//# sourceMappingURL=amcdnl-ngx-echarts.js.map
