import { ChangeDetectionStrategy, Component, ElementRef, EventEmitter, Input, NgZone, Output, NgModule } from '@angular/core';
import { take, distinctUntilChanged, debounceTime, takeUntil } from 'rxjs/operators';
import { fromEvent, Subject } from 'rxjs';
import { CommonModule } from '@angular/common';

var EChartsComponent = /** @class */ (function () {
    function EChartsComponent(_elementRef, _ngZone) {
        this._elementRef = _elementRef;
        this._ngZone = _ngZone;
        this.chartClick = new EventEmitter();
        this.chartDblClick = new EventEmitter();
        this.chartMouseDown = new EventEmitter();
        this.chartMouseUp = new EventEmitter();
        this.chartMouseOver = new EventEmitter();
        this.chartMouseOut = new EventEmitter();
        this.chartGlobalOut = new EventEmitter();
        this.chartContextMenu = new EventEmitter();
        this.chartDataZoom = new EventEmitter();
        this._loaded = false;
        this._destroy$ = new Subject();
    }
    EChartsComponent.prototype.ngOnInit = function () {
        var _this = this;
        this._ngZone.onStable
            .pipe(take(1))
            .subscribe(function () { return _this._createChart(); });
        this._ngZone.runOutsideAngular(function () {
            fromEvent(window, 'resize')
                .pipe(distinctUntilChanged(), debounceTime(10), takeUntil(_this._destroy$)).subscribe(function () { return _this.resize(); });
        });
    };
    EChartsComponent.prototype.ngOnChanges = function (changes) {
        if (this._chart && this._loaded) {
            var result = {};
            for (var change in changes) {
                if (this[change]) {
                    result[change] = changes[change].currentValue;
                }
            }
            this.setOptions(result);
        }
    };
    EChartsComponent.prototype.ngOnDestroy = function () {
        if (this._chart) {
            this._chart.dispose();
            this._chart = null;
        }
        this._destroy$.next();
        this._destroy$.complete();
    };
    EChartsComponent.prototype.resize = function () {
        if (this._chart) {
            this._chart.resize();
        }
    };
    EChartsComponent.prototype.setOptions = function (changes) {
        this._chart.setOption(changes);
    };
    EChartsComponent.prototype._createChart = function () {
        var _this = this;
        this._ngZone.runOutsideAngular(function () {
            _this._chart = echarts.init(_this._elementRef.nativeElement, _this.theme);
            _this._chart.on('click', function (e) { return _this._ngZone.run(function () { return _this.chartClick.emit(e); }); });
            _this._chart.on('dblClick', function (e) { return _this._ngZone.run(function () { return _this.chartDblClick.emit(e); }); });
            _this._chart.on('mousedown', function (e) { return _this._ngZone.run(function () { return _this.chartMouseDown.emit(e); }); });
            _this._chart.on('mouseup', function (e) { return _this._ngZone.run(function () { return _this.chartMouseUp.emit(e); }); });
            _this._chart.on('mouseover', function (e) { return _this._ngZone.run(function () { return _this.chartMouseOver.emit(e); }); });
            _this._chart.on('mouseout', function (e) { return _this._ngZone.run(function () { return _this.chartMouseOut.emit(e); }); });
            _this._chart.on('globalout', function (e) { return _this._ngZone.run(function () { return _this.chartGlobalOut.emit(e); }); });
            _this._chart.on('contextmenu', function (e) { return _this._ngZone.run(function () { return _this.chartContextMenu.emit(e); }); });
            _this._chart.on('datazoom', function (e) { return _this._ngZone.run(function () { return _this.chartDataZoom.emit(e); }); });
            _this.setOptions({
                visualMap: _this.visualMap,
                title: _this.title,
                tooltip: _this.tooltip,
                legend: _this.legend,
                series: _this.series,
                xAxis: _this.xAxis,
                yAxis: _this.yAxis,
                animation: _this.animation
            });
            _this._loaded = true;
        });
    };
    return EChartsComponent;
}());
EChartsComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-echart',
                template: "<ng-content></ng-content>",
                changeDetection: ChangeDetectionStrategy.OnPush,
                host: {
                    '[class.ngx-echart]': 'true'
                }
            },] },
];
EChartsComponent.ctorParameters = function () { return [
    { type: ElementRef },
    { type: NgZone }
]; };
EChartsComponent.propDecorators = {
    theme: [{ type: Input }],
    title: [{ type: Input }],
    tooltip: [{ type: Input }],
    legend: [{ type: Input }],
    series: [{ type: Input }],
    loading: [{ type: Input }],
    xAxis: [{ type: Input }],
    yAxis: [{ type: Input }],
    visualMap: [{ type: Input }],
    animation: [{ type: Input }],
    chartClick: [{ type: Output }],
    chartDblClick: [{ type: Output }],
    chartMouseDown: [{ type: Output }],
    chartMouseUp: [{ type: Output }],
    chartMouseOver: [{ type: Output }],
    chartMouseOut: [{ type: Output }],
    chartGlobalOut: [{ type: Output }],
    chartContextMenu: [{ type: Output }],
    chartDataZoom: [{ type: Output }]
};
var EChartsModule = /** @class */ (function () {
    function EChartsModule() {
    }
    return EChartsModule;
}());
EChartsModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [EChartsComponent],
                exports: [EChartsComponent]
            },] },
];

export { EChartsModule, EChartsComponent };
//# sourceMappingURL=amcdnl-ngx-echarts.js.map
